@@ -1,6 +1,6 @@
 /*
  * xinstall.c
- * $Id: xinstall.c 35030 2008-03-14 23:49:07Z ryandesign@macports.org $
+ * $Id: xinstall.c 53831 2009-07-15 04:05:51Z toby@macports.org $
  * Copyright (c) 1987, 1993
  *	The Regents of the University of California.  All rights reserved.
  *
@@ -70,6 +70,8 @@
 
 #include <tcl.h>
 
+#include "Pextlib.h"
+
 #if HAVE_PATHS_H
 #include <paths.h>
 #endif
@@ -78,6 +80,8 @@
 #define _PATH_DEVNULL	"/dev/null"
 #endif
 
+#include "xinstall.h"
+
 #ifndef MAXBSIZE
 #define MAXBSIZE 65536
 #endif
@@ -137,8 +141,6 @@ static void	strip(const char *);
 static int	trymmap(int);
 static void	usage(Tcl_Interp *interp);
 
-extern int	ui_info(Tcl_Interp *interp, char *mesg);
-
 int
 InstallCmd(ClientData clientData UNUSED, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[])
 {
